@@ -1,9 +1,11 @@
-from indicoio.utils.api import api_handler
-from indicoio.utils.decorators import detect_batch_decorator
+from ..utils.api import api_handler
+from ..utils.decorators import detect_batch_decorator
 
 
 @detect_batch_decorator
-def keywords(text, cloud=None, batch=False, api_key=None, version=None, **kwargs):
+def keywords(
+    text, cloud=None, batch=False, api_key=None, version=2, batch_size=None, **kwargs
+):
     """
     Given input text, returns series of keywords and associated scores
 
@@ -22,5 +24,14 @@ def keywords(text, cloud=None, batch=False, api_key=None, version=None, **kwargs
     :type text: str or unicode
     :rtype: Dictionary of feature score pairs
     """
+    if kwargs.get("language", "english") != "english":
+        version = 1
     url_params = {"batch": batch, "api_key": api_key, "version": version}
-    return api_handler(text, cloud=cloud, api="keywords", url_params=url_params, **kwargs)
+    return api_handler(
+        text,
+        cloud=cloud,
+        api="keywords",
+        url_params=url_params,
+        batch_size=batch_size,
+        **kwargs
+    )
